# Installation

The preferred installation is via [uv](https://docs.astral.sh/uv/guides/tools/).

```shell
uv tool install check-config
```

As it is packages as a Python application, you can also install it via pip(x):

```shell
pip install check-config
pipx install check-config
```

Alternatively you can use, which does not need Python:

```shell
cargo install check-config
```
